example of sharing plugins between projects
overwriting the plugin settings

- no need to inherit the plugin just to change the values
- less code, quicker setup
- we can overwrite plugin settings from 3rd party plugins, adding support for a shared marketplace